@@ -8,7 +8,7 @@ from typing import Any, Dict, Optional, Tuple
 import numpy as np
 import pyrr
 
-from payton.math.functions import sub_vector, vector_transform_4
+from payton.math.functions import add_vectors, sub_vector, vector_transform_4
 from payton.math.geometry import raycast_plane_intersect
 from payton.math.vector import Vector3D
 from payton.scene.geometry.base import Object
@@ -55,10 +55,15 @@ class Camera:
         self.up = [0.0, 0.0, 1.0] if up is None else up
 
         self.target_object: Optional[Object] = target_object
+        self._previous_target_location: Optional[Vector3D] = None
         self.fov: float = fov
         self.aspect_ratio: float = aspect_ratio
         self._near: float = near
         self._far: float = far
+        self.min_elevation = -1
+        self.max_elevation = -1
+        self.min_distance = 0
+        self.max_distance = -1
 
         # zoom factor for Orthographic projection
         self._zoom: float = zoom
@@ -159,30 +164,34 @@ class Camera:
         self._use_cache = False
 
     def rotate_around_target(self, phi: float, theta: float) -> None:
-        """Rotate the camera around the target
+        """Rotate the camera around the target.
 
         NOTE: This method works with Spherical Coordinates!
         https://en.wikipedia.org/wiki/Spherical_coordinate_system
-
         Keyword arguments:
         phi -- Phi angle in radians
-        theta -- Theta angle in radians
-        """
+        theta -- Theta angle in radians"""
 
         diff = sub_vector(self.position, self.target)
 
         r = self.distance()
-        _theta = math.acos(diff[2] / r)
-        _phi = math.atan2(diff[1], diff[0])
+        current_theta = math.acos(diff[2] / r)
+        current_phi = math.atan2(diff[1], diff[0])
 
-        _ct = _theta + math.radians(theta)
-        _cp = _phi + math.radians(phi)
-        _ct = max(_ct, 0.001)
-        _ct = min(_ct, 3.13)
+        if self.min_elevation != -1 and current_theta < self.min_elevation:
+            current_theta = self.min_elevation
 
-        x = r * math.sin(_ct) * math.cos(_cp)
-        y = r * math.sin(_ct) * math.sin(_cp)
-        z = r * math.cos(_ct)
+        if self.max_elevation != -1 and current_theta > self.max_elevation:
+            current_theta = self.max_elevation
+
+        ct = current_theta + math.radians(theta)
+        cp = current_phi + math.radians(phi)
+        ct = max(ct, 0.001)
+        ct = min(ct, 3.13)
+
+        x = r * math.sin(ct) * math.cos(cp)
+        y = r * math.sin(ct) * math.sin(cp)
+        z = r * math.cos(ct)
 
         self.position = [
             x + self.target[0],
@@ -280,6 +289,13 @@ class Camera:
         if not self.perspective:
             self.zoom = distance
             return
+
+        if self.max_distance != -1:
+            if distance > self.max_distance:
+                distance = self.max_distance
+        if distance < self.min_distance:
+            distance = self.min_distance
+
         diff = sub_vector(self.position, self.target)
         _theta = math.acos(diff[2] / self.distance())
         _phi = math.atan2(diff[1], diff[0])
@@ -292,7 +308,7 @@ class Camera:
         self._use_cache = False
 
     def render(self) -> Tuple[np.ndarray, np.ndarray]:
-        """Render the camera"""
+        """Render the camera."""
         if self._use_cache and self.target_object is None and self._projection is not None and self._view is not None:
             return self._projection, self._view
 
@@ -325,7 +341,13 @@ class Camera:
 
         if self.target_object:
             # I believe there is a bug at mypy about @property methods
+            if self._previous_target_location is None:
+                self._previous_target_location = self.target_object.position
+            target_diff = sub_vector(self.target_object.position, self._previous_target_location)
+            self.position = add_vectors(self.position, target_diff)
+            eye = np.array(list(self.position), dtype=np.float32)
             self.target = self.target_object.position
+            self._previous_target_location = self.target_object.position
 
         target = np.array(list(self.target), dtype=np.float32)
         up = np.array(list(self.up), dtype=np.float32)
